//
//  HalfView.m
//  TopHits
//
//  Created by Craig Hockenberry on 10/31/23.
//

#import "HalfView.h"

@implementation HalfView

- (void)drawRect:(NSRect)dirtyRect
{
    [super drawRect:dirtyRect];

	NSRect bounds = self.bounds;

	// NOTE: This view draws the top half in a color: green when its window is active, and red
	// when it's not. The bottom half is always transparent.
	//
	// After this view is redrawn the first time, the window server will only activate the app
	// when clicking on the transparent portion of the view. The semi-opaque top portion does not
	// detect clicks.
	
	// top half
	{
		NSRect drawRect = NSMakeRect(bounds.origin.x, NSMidY(bounds), bounds.size.width, NSMidY(bounds));
		NSColor *drawColor = nil;
		if (self.window.isKeyWindow) {
			drawColor = NSColor.greenColor;
		}
		else {
			drawColor = NSColor.redColor;
		}
		[[drawColor colorWithAlphaComponent:0.5] set];
		NSRectFill(drawRect);
	}

	// bottom half
	{
		NSRect drawRect = NSMakeRect(bounds.origin.x, NSMinY(bounds), bounds.size.width, NSMidY(bounds));
		[NSColor.clearColor set];
		NSRectFill(drawRect);
	}

	[NSColor.blackColor set];
	NSFrameRect(bounds);
}

@end
